@@ -1,12 +1,12 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "lsp-latex" "3.11.0"
+(define-package "lsp-latex" "20251104.1507"
   "LSP-mode client for LaTeX, on texlab."
   '((emacs    "29.1")
     (lsp-mode "6.0")
     (consult  "0.35"))
   :url "https://github.com/ROCKTAKEY/lsp-latex"
   :commit "a9ac457141f0aa15505b61ded3f12d0ad477b771"
-  :revdesc "v3.11.0-0-ga9ac457141f0"
+  :revdesc "a9ac457141f0"
   :keywords '("languages" "tex")
   :authors '(("ROCKTAKEY" . "rocktakey@gmail.com"))
   :maintainers '(("ROCKTAKEY" . "rocktakey@gmail.com")))
